@@ -54,9 +54,9 @@ void YouTube::checkIfSignedOut() {
         return;
     }
 
+    emit signedOut();
     int statusCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
     if (statusCode == 200) {
-        emit signedOut();
         emit alert(tr("You have signed out of your YouTube account"));
     }
     else {
@@ -421,6 +421,27 @@ void YouTube::deleteFromFavourites(const QStringList &ids) {
     connect(this, SIGNAL(postSuccessful(QString)), this, SIGNAL(deletedFromFavourites()));
 }
 
+void YouTube::deleteFromUploads(const QStringList &ids) {
+    QUrl url("http://gdata.youtube.com/feeds/api/users/" + username + "/uploads/batch?v=2");
+    QByteArray xml("<feed xmlns='http://www.w3.org/2005/Atom'\n" \
+                   "xmlns:media='http://search.yahoo.com/mrss/'\n" \
+                   "xmlns:batch='http://schemas.google.com/gdata/batch'\n" \
+                   "xmlns:yt='http://gdata.youtube.com/schemas/2007'>\n" \
+                   "<batch:operation type=\"delete\"/>\n");
+
+    foreach(QString id, ids) {
+        xml.append("<entry>\n" \
+                   "<batch:operation type=\"delete\"/>\n" \
+                   "<id>" + id.toAscii() + "</id>\n" \
+                   "<link rel='edit' type='application/atom+xml'\n" \
+                   "href='http://gdata.youtube.com/feeds/api/users/" + username.toAscii() + "/favorites/" + id.split(":").at(3).toAscii() + "?v=2'/>\n" \
+                   "</entry>\n");
+    }
+    xml.append("</feed>");
+    postRequest(url, xml);
+    connect(this, SIGNAL(postSuccessful(QString)), this, SIGNAL(deletedFromUploads()));
+}
+
 void YouTube::addToPlaylist(const QStringList &ids, const QString &playlistId) {
     QUrl url("http://gdata.youtube.com/feeds/api/playlists/" + playlistId + "/batch?v=2");
     QByteArray xml("<feed xmlns='http://www.w3.org/2005/Atom'\n" \
